/*******************************************************************************
*                                                                              *
*   NetBurner MOD5234 General Purpose Input/Output Header File                 *
*   gpio5234.h                                                                 *
*                                                                              *
*******************************************************************************/


////////////////////////////////////////////////////////////////////////////////
// GPIO Pin Assignment Register Definitions. All signals are referenced to their
// primary functions. Writing the complement of each of the following defined
// values associated with a signal in the register will configure the
// corresponding pin for GPIO.
//

//
// For use with external bus control port pin assignment register: sim.gpio.par_busctl.
//
#define GPIO_PAR_TA         ( 0x1000 )   // Bit      12 - Transfer Acknowledge

//
// For use with I2C port pin assignment register: sim.gpio.par_feci2c.
//
#define GPIO_PAR_SDA        (   0x03 )   // Bit  1 -  0 - I2C Serial Data
#define GPIO_PAR_SCL        (   0x0C )   // Bit  3 -  2 - I2C Serial Clock

//
// For use with UART port pin assignment register: sim.gpio.par_uart.
//
#define GPIO_PAR_U0RTS      ( 0x0001 )   // Bit       0 - UART 0 Request to Send
#define GPIO_PAR_U0CTS      ( 0x0002 )   // Bit       1 - UART 0 Clear to Send
#define GPIO_PAR_U0TXD      ( 0x0004 )   // Bit       2 - UART 0 Transmit
#define GPIO_PAR_U0RXD      ( 0x0008 )   // Bit       3 - UART 0 Receive
#define GPIO_PAR_U1RTS      ( 0x0030 )   // Bit  5 -  4 - UART 1 Request to Send
#define GPIO_PAR_U1CTS      ( 0x00C0 )   // Bit  7 -  6 - UART 1 Clear to Send
#define GPIO_PAR_U1TXD      ( 0x0300 )   // Bit  9 -  8 - UART 1 Transmit
#define GPIO_PAR_U1RXD      ( 0x0C00 )   // Bit 11 - 10 - UART 1 Receive
#define GPIO_PAR_U2TXD      ( 0x1000 )   // Bit      12 - UART 2 Transmit
#define GPIO_PAR_U2RXD      ( 0x2000 )   // Bit      13 - UART 2 Receive

//
// For use with QSPI port pin asssignment register: sim.gpio.par_qspi.
//
#define GPIO_PAR_SPICLK     (   0x03 )   // Bit  1 -  0 - SPI Clock
#define GPIO_PAR_SPIDOUT    (   0x04 )   // Bit       2 - SPI Data Out
#define GPIO_PAR_SPIDIN     (   0x18 )   // Bit  4 -  3 - SPI Data In
#define GPIO_PAR_SPICS0     (   0x20 )   // Bit       5 - SPI Chip Select 0
#define GPIO_PAR_SPICS1     (   0xC0 )   // Bit  7 -  6 - SPI Chip Select 1

//
// For use with DMA timer port pin assignment register: sim.gpio.par_timer.
//
#define GPIO_PAR_DT0OUT     ( 0x0003 )   // Bit  1 -  0 - DMA Timer Output 0
#define GPIO_PAR_DT1OUT     ( 0x000C )   // Bit  3 -  2 - DMA Timer Output 1
#define GPIO_PAR_DT2OUT     ( 0x0030 )   // Bit  5 -  4 - DMA Timer Output 2
#define GPIO_PAR_DT0IN      ( 0x0300 )   // Bit  9 -  8 - DMA Timer Input 0
#define GPIO_PAR_DT1IN      ( 0x0C00 )   // Bit 11 - 10 - DMA Timer Input 1

//
// For use with ETPU port pin assignment register: sim.gpio.par_etpu.
//
#define GPIO_PAR_LTPUODIS   (   0x01 )   // Bit       0 - Lower TPU Channel Output Disable
#define GPIO_PAR_UTPUODIS   (   0x02 )   // Bit       1 - Upper TPU Channel Output Disable
#define GPIO_PAR_TCRCLK     (   0x04 )   // Bit       2 - TPU Time Base Clock


////////////////////////////////////////////////////////////////////////////////
// GPIO Port Data Direction Register and Port Output Data Register Definitions.
// The following defined values are only for use on corresponding pins that are
// configured for GPIO.
//
// Port Data Direction Register
// Write: 0 = Input, 1 = Output
//
// Port Output Data Register
// Write: 0 = Low, 1 = High
// Read: The current values in the register (not the port pin values)
//

//
// For use with external bus control port data direction register and port
// output data register: sim.gpio.pddr_busctl, sim.gpio.podr_busctl.
//
#define PDDR_PODR_TA        (   0x40 )   // Bit 6 - Transfer Acknowledge

//
// For use with I2C port data direction register and port output data register:
// sim.gpio.pddr_feci2c, sim.gpio.podr_feci2c.
//
#define PDDR_PODR_SDA       (   0x01 )   // Bit 0 - I2C Serial Data
#define PDDR_PODR_SCL       (   0x02 )   // Bit 1 - I2C Serial Clock

//
// For use with UART port data direction register and port output data register:
// sim.gpio.pddr_uartl, sim.gpio.podr_uartl.
//
#define PDDR_PODR_U0RTS     (   0x04 )   // Bit 2 - UART 0 Request to Send
#define PDDR_PODR_U0CTS     (   0x08 )   // Bit 3 - UART 0 Clear to Send
#define PDDR_PODR_U0TXD     (   0x02 )   // Bit 1 - UART 0 Transmit
#define PDDR_PODR_U0RXD     (   0x01 )   // Bit 0 - UART 0 Receive
#define PDDR_PODR_U1RTS     (   0x40 )   // Bit 6 - UART 1 Request to Send
#define PDDR_PODR_U1CTS     (   0x80 )   // Bit 7 - UART 1 Clear to Send
#define PDDR_PODR_U1TXD     (   0x20 )   // Bit 5 - UART 1 Transmit
#define PDDR_PODR_U1RXD     (   0x10 )   // Bit 4 - UART 1 Receive

//
// For use with UART port data direction register and port output data register:
// sim.gpio.pddr_uarth, sim.gpio.podr_uarth.
//
#define PDDR_PODR_U2TXD     (   0x02 )   // Bit 1 - UART 2 Transmit
#define PDDR_PODR_U2RXD     (   0x01 )   // Bit 0 - UART 2 Receive

//
// For use with QSPI port data direction register and port output data register:
// sim.gpio.pddr_qspi, sim.gpio.podr_qspi.
//
#define PDDR_PODR_SPICLK    (   0x04 )   // Bit 2 - SPI Clock
#define PDDR_PODR_SPIDOUT   (   0x01 )   // Bit 0 - SPI Data Out
#define PDDR_PODR_SPIDIN    (   0x02 )   // Bit 1 - SPI Data In
#define PDDR_PODR_SPICS0    (   0x08 )   // Bit 3 - SPI Chip Select 0
#define PDDR_PODR_SPICS1    (   0x10 )   // Bit 4 - SPI Chip Select 1

//
// For use with DMA timer port data direction register and port output data
// register: sim.gpio.pddr_timer, sim.gpio.podr_timer.
//
#define PDDR_PODR_DT0OUT    (   0x01 )   // Bit 0 - DMA Timer Output 0
#define PDDR_PODR_DT1OUT    (   0x04 )   // Bit 2 - DMA Timer Output 1
#define PDDR_PODR_DT2OUT    (   0x10 )   // Bit 4 - DMA Timer Output 2
#define PDDR_PODR_DT0IN     (   0x02 )   // Bit 1 - DMA Timer Input  0
#define PDDR_PODR_DT1IN     (   0x08 )   // Bit 3 - DMA Timer Input  1

//
// For use with ETPU port data direction register and port output data register:
// sim.gpio.pddr_etpu, sim.gpio.podr_etpu.
//
#define PDDR_PODR_LTPUODIS  (   0x01 )   // Bit 0 - Lower TPU Channel Output Disable
#define PDDR_PODR_UTPUODIS  (   0x02 )   // Bit 1 - Upper TPU Channel Output Disable
#define PDDR_PODR_TCRCLK    (   0x04 )   // Bit 2 - TPU Time Base Clock

//
// For use with edge port data direction register and port output data register:
// sim.eport.epddr, sim.eport.epdr.
//
#define PDDR_PDR_IRQ1       (   0x02 )   // Bit 1 - External Interrupt 1
#define PDDR_PDR_IRQ3       (   0x08 )   // Bit 3 - External Interrupt 3
#define PDDR_PDR_IRQ5       (   0x20 )   // Bit 5 - External Interrupt 5
#define PDDR_PDR_IRQ7       (   0x80 )   // Bit 7 - External Interrupt 7
